searchNodes=[{"doc":"Mockingjay is a library for compiling trained decision trees to Nx defn functions. It is based on the paper Taming Model Serving Complexity, Performance and Cost: A Compilation to Tensor Computations Approach and the accompanying Hummingbird library from Microsoft. Protocol Mockingjay can be used with any model that implements the Mockingjay.DecisionTree protocol. For an example implementation, this protocol is implemented by EXGBoost in its EXGBoost.Compile module. This protocol is used to extract the trees from the model and to get the number of classes and features in the model. Strategies Mockingjay supports three strategies for compiling decision trees: :gemm , :tree_traversal , and :perfect_tree_traversal , or :auto to select using heuristics. The :auto strategy will select the best strategy based on the depth of the tree according to the following rules: GEMM: Shallow Trees (&lt;=3) PerfectTreeTraversal: Tall trees where depth &lt;= 10 TreeTraversal: Tall trees unfit for PerfectTreeTraversal (depth &gt; 10) Conversion Pipeline Mockingjay compiles a model using a pipeline composed of three functions, all of which take a Nx.Container.t() and returns a Nx.Container.t(). These functions will be determined by the strategy chosen, but can also be specified manually. Practically speaking, you should not need to specify these manually (especially the forward function). The functions are: forward - The forward function -- determined by strategy aggregate - Aggregates the output of the forward function -- determined by strategy and output type (ensemble or single tree) post_transform - Applies a post transform to the output of the aggregate function -- determined by strategy and output type (classification or regression) The convert function returns a defn function that takes a Nx.Container.t() and returns a Nx.Container.t(), running the input through the pipeline (forward -&gt; aggregate -&gt; post_transform).","ref":"Mockingjay.html","title":"Mockingjay","type":"module"},{"doc":"Compiles a model that implements the Mockingjay.DecisionTree protocol to a defn function. Options :reorder_trees - whether to reorder the trees in the model to optimize inference accuracy. Defaults to true . This assumes that trees are ordere such that they classify classes in order 0..n then repeat (e.g. a cyclic class prediction). If this is not the case, set this to false and implement custom ordering in the DecisionTree protocol implementation. :forward - the forward function to use. A function that takes a Nx.Container.t() and returns a Nx.Container.t(). If none is specified, the best option will be chosen based on the output type of the model. :aggregate - The aggregation function to use. A function that takes a Nx.Container.t() and returns a Nx.Container.t(). If none is specified, the best option will be chosen based on the output type of the model. :post_transform - the post transform to use. A function that takes a Nx.Container.t() and returns a Nx.Container.t(). If none is specified, the best option will be chosen based on the output type of the model.","ref":"Mockingjay.html#convert/2","title":"Mockingjay.convert/2","type":"function"},{"doc":"A protocol for extracting decision trees from a model and getting information about the model. This protocol can be used for any model that uses decision trees as its base model. As such, this can be used for both ensemble and single decision tree models. This protocol requires that the model implement the Mockingjay.Tree struct for representing decision trees. This protocol also requires that all decsision split conditions in the model are the same condition. The model does not need to be a perfect binary tree, but it must be a binary tree.","ref":"Mockingjay.DecisionTree.html","title":"Mockingjay.DecisionTree","type":"protocol"},{"doc":"Returns the condition used to split the data.","ref":"Mockingjay.DecisionTree.html#condition/1","title":"Mockingjay.DecisionTree.condition/1","type":"function"},{"doc":"Returns the number of classes in the model.","ref":"Mockingjay.DecisionTree.html#num_classes/1","title":"Mockingjay.DecisionTree.num_classes/1","type":"function"},{"doc":"Returns the number of features in the model.","ref":"Mockingjay.DecisionTree.html#num_features/1","title":"Mockingjay.DecisionTree.num_features/1","type":"function"},{"doc":"Returns a list of Mockingjay.Tree struct representing the decision tree.","ref":"Mockingjay.DecisionTree.html#trees/1","title":"Mockingjay.DecisionTree.trees/1","type":"function"},{"doc":"","ref":"Mockingjay.DecisionTree.html#t:t/0","title":"Mockingjay.DecisionTree.t/0","type":"type"},{"doc":"A struct containing a convenient in-memory representation of a decision tree. Each &quot;node&quot; in the tree is a Tree struct. A &quot;decision&quot; or &quot;inner&quot; node is any node whose :left and :right values are a valid Tree . A &quot;leaf&quot; or &quot;outer&quot; node is any node whose :left and :right values are nil . :left and :right must either both be nil or both be a Tree . :id - The id of the node. This is a unique reference. This is generated automatically when using the from_map function. :left - The left child of the node. This is nil for leaf nodes. This is a Tree for decision nodes. :right - The right child of the node. This is nil for leaf nodes. This is a Tree for decision nodes. :value - The value of the node: For leaf nodes, this is the value as a number. For non-leaf nodes, this is a map containing the following keys: :feature - The feature used to split the data (if it is not a leaf). :threshold - The threshold used to split the data (if it is not a leaf).","ref":"Mockingjay.Tree.html","title":"Mockingjay.Tree","type":"module"},{"doc":"Returns a list of nodes in BFS order. For the uses in Mockingjay, BFS is tree-level order from right to left on each level. The nodes include their children nodes.","ref":"Mockingjay.Tree.html#bfs/1","title":"Mockingjay.Tree.bfs/1","type":"function"},{"doc":"Checks is the given child_id exists in the tree.","ref":"Mockingjay.Tree.html#child?/2","title":"Mockingjay.Tree.child?/2","type":"function"},{"doc":"Returns the depth of the tree. The root node is at depth 0.","ref":"Mockingjay.Tree.html#depth/1","title":"Mockingjay.Tree.depth/1","type":"function"},{"doc":"Returns the depth of the tree starting from the given level.","ref":"Mockingjay.Tree.html#depth_from_level/2","title":"Mockingjay.Tree.depth_from_level/2","type":"function"},{"doc":"Returns tree nodes as a list in DFS order.","ref":"Mockingjay.Tree.html#dfs/1","title":"Mockingjay.Tree.dfs/1","type":"function"},{"doc":"Returns a Tree struct from a map. The map must have the appropriate required keys for the Tree struct. Any extra keys are ignored.","ref":"Mockingjay.Tree.html#from_map/1","title":"Mockingjay.Tree.from_map/1","type":"function"},{"doc":"Returns a list of the decision nodes in the tree in BFS order.","ref":"Mockingjay.Tree.html#get_decision_nodes/1","title":"Mockingjay.Tree.get_decision_nodes/1","type":"function"},{"doc":"Returns a list of the values of the decision nodes in the tree in BFS order.","ref":"Mockingjay.Tree.html#get_decision_values/1","title":"Mockingjay.Tree.get_decision_values/1","type":"function"},{"doc":"Returns a list of the leaf nodes in the tree in BFS order.","ref":"Mockingjay.Tree.html#get_leaf_nodes/1","title":"Mockingjay.Tree.get_leaf_nodes/1","type":"function"},{"doc":"Returns a list of the values of the leaf nodes in the tree in BFS order.","ref":"Mockingjay.Tree.html#get_leaf_values/1","title":"Mockingjay.Tree.get_leaf_values/1","type":"function"},{"doc":"Traverse the tree in BFS order, applying a reducer function to each node.","ref":"Mockingjay.Tree.html#reduce_tree/3","title":"Mockingjay.Tree.reduce_tree/3","type":"function"},{"doc":"A simple binary tree implementation.","ref":"Mockingjay.Tree.html#t:t/0","title":"Mockingjay.Tree.t/0","type":"type"}]